utils::globalVariables(c("vl", "time", "id",
                         "vl_diff", "index", "tag", "n",
                         "firstbelow",
                         "calculation", "model", "Model",
                         "Included",
                         "Param", "param", "estimate",
                         "A", "B", "delta", "gamma", "Bhat", "gammahat", "omega",
                         "ShortLifespan", "LongLifespan", "SingleLifespan",
                         "LongLifespanNonProductive", "ShortLifespanProductive", "ShortLifespanNonProductive",
                         "Median", "SD",
                         "TTS", "ART", "fit",
                         "lowerCI", "upperCI", "CIrange", "relativerange",
                         "."))
